@@ -52,5 +52,5 @@ struct app_data {
 /*
  * Function definitons
  */
-app_data_t* app_init();
+app_data_t* app_init(void);
 void app_free(app_data_t *myapp);
