@@ -22,6 +22,7 @@
 
 #include <hildon-extras/he-fullscreen-button.h>
 #include <hildon-extras/he-helper.h>
+#include <hildon-extras/he-about-dialog.h>
 #include <libraw/libraw.h>
 
 #include "appdata.h"
@@ -40,6 +41,7 @@ void create_app(app_data_t *myapp) {
 	GtkWidget *openitem;
 	GtkWidget *imgdetitem;
 	GtkWidget *fullscreenitem;
+	GtkWidget *camlistitem;
 	GtkWidget *aboutitem;
 	GtkWidget *panarea;
     GtkWidget *eventbox;
@@ -65,19 +67,23 @@ void create_app(app_data_t *myapp) {
 	/* Add menu buttons */
     openitem = gtk_button_new_with_label("Open image");
     g_signal_connect_after(G_OBJECT (openitem),"clicked",G_CALLBACK (open_image_file),myapp);
-    hildon_app_menu_insert(appmenu,GTK_BUTTON(openitem),2);
+    hildon_app_menu_insert(appmenu,GTK_BUTTON(openitem),0);
 
     imgdetitem = gtk_button_new_with_label((myapp->showimgparam ? "Hide details" : "View details"));
     g_signal_connect_after(G_OBJECT (imgdetitem),"clicked",G_CALLBACK (toggle_image_details),myapp);
-    hildon_app_menu_insert(appmenu,GTK_BUTTON (imgdetitem),3);
+    hildon_app_menu_insert(appmenu,GTK_BUTTON (imgdetitem),1);
 
-    fullscreenitem = gtk_button_new_with_label("Go fullscreen");
+    fullscreenitem = gtk_button_new_with_label("Fullscreen");
     g_signal_connect_after(G_OBJECT (fullscreenitem),"clicked",G_CALLBACK (toggle_fullscreen_mode),myapp);
-    hildon_app_menu_insert(appmenu,GTK_BUTTON (fullscreenitem),4);
+    hildon_app_menu_insert(appmenu,GTK_BUTTON (fullscreenitem),2);
+
+    camlistitem = gtk_button_new_with_label("Supported cameras");
+    g_signal_connect_after(G_OBJECT (camlistitem),"clicked",G_CALLBACK (create_camera_list),myapp);
+    hildon_app_menu_insert(appmenu,GTK_BUTTON(camlistitem),3);
 
     aboutitem = gtk_button_new_with_label("About");
     g_signal_connect_after(G_OBJECT (aboutitem),"clicked",G_CALLBACK (create_about),myapp);
-    hildon_app_menu_insert(appmenu,GTK_BUTTON(aboutitem),5);
+    hildon_app_menu_insert(appmenu,GTK_BUTTON(aboutitem),4);
 
     /* Add the main manu to the app itself */
     gtk_widget_show_all(GTK_WIDGET (appmenu));
@@ -89,6 +95,7 @@ void create_app(app_data_t *myapp) {
     gtk_widget_show(GTK_WIDGET (panarea));
     gtk_container_add(GTK_CONTAINER (myapp->mainwin),panarea);
     eventbox = gtk_event_box_new();
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX (eventbox),FALSE);
     gtk_widget_show(eventbox);
     gtk_widget_set_events(eventbox,GDK_BUTTON_PRESS | GDK_BUTTON_RELEASE | GDK_KEY_PRESS);
     myapp->image = GTK_WIDGET (gtk_image_new());
@@ -149,41 +156,56 @@ void create_app(app_data_t *myapp) {
  * Create the About dialog
  */
 void create_about(GtkWidget *callerobj,app_data_t *myapp) {
-	GtkWidget *abdialog;
-	GtkWidget *appicon;
-	GtkWidget *copyright;
-	GtkWidget *separator;
+	gchar *iconfile;
+
+	iconfile = g_strconcat(HILDONPIXMAPDIR,"/",PACKAGE,".png",NULL);
+	he_about_dialog_present(GTK_WINDOW (myapp->mainwin),PACKAGE,PACKAGE,VERSION,
+							"Viewer for RAW image file formats","(C) 2009 Luca Donaggio (donaggio@gmail.com)",
+							"http://mrawviewer.garage.maemo.org","https://garage.maemo.org/tracker/?group_id=1000",
+							"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=M2ZUQJU6CN9WY&lc=US&item_name=MRAWViewer%20by%20L%2e%20Donaggio&item_number=mrawviewer&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted");
+	g_free(iconfile);
+}
+
+/*
+ * Create the Supported Cameras dialog
+ */
+void create_camera_list(GtkWidget *callerobj,app_data_t *myapp) {
+	GtkWidget *cldialog;
 	GtkWidget *panarea;
 	GtkWidget *dispmessage;
 	gchar *message;
 	const char **cameralist;
 	gint i;
+	gboolean arbutenabled;
 
-	abdialog = gtk_dialog_new();
-	gtk_window_set_title(GTK_WINDOW (abdialog),g_strconcat("About ",PACKAGE," ",VERSION,NULL));
-	gtk_window_set_default_size(GTK_WINDOW (abdialog),-1,400);
-	appicon = GTK_WIDGET (gtk_image_new_from_file(g_strconcat(HILDONPIXMAPDIR,"/",PACKAGE,".png",NULL)));
-	gtk_box_pack_start(GTK_BOX (GTK_DIALOG (abdialog)->vbox),appicon,FALSE,FALSE,10);
-	copyright = gtk_label_new(NULL);
-	gtk_label_set_markup(GTK_LABEL (copyright),"<span size=\"small\" style=\"italic\">(C) 2009 Luca Donaggio (donaggio@gmail.com)</span>");
-	gtk_box_pack_start(GTK_BOX (GTK_DIALOG (abdialog)->vbox),copyright,FALSE,FALSE,10);
-	separator = gtk_hseparator_new();
-	gtk_box_pack_start(GTK_BOX (GTK_DIALOG (abdialog)->vbox),separator,FALSE,FALSE,10);
+    arbutenabled = (arrow_button_is_enabled(myapp->prevarrowbut) && arrow_button_is_enabled(myapp->nextarrowbut));
+	cldialog = gtk_dialog_new();
+	gtk_window_set_modal(GTK_WINDOW (cldialog),TRUE);
+	gtk_window_set_transient_for(GTK_WINDOW (cldialog),GTK_WINDOW (myapp->mainwin));
+	gtk_window_set_destroy_with_parent(GTK_WINDOW (cldialog),TRUE);
+	gtk_window_set_title(GTK_WINDOW (cldialog),g_strconcat(PACKAGE," - Supported cameras",NULL));
+	gtk_window_set_default_size(GTK_WINDOW (cldialog),-1,320);
 	panarea = GTK_WIDGET (hildon_pannable_area_new());
 	dispmessage = gtk_label_new(NULL);
 	gtk_label_set_line_wrap(GTK_LABEL (dispmessage),TRUE);
-	message = g_strconcat("<b>",PACKAGE,"</b> is an image viewer for the Maemo platform supporting RAW image file formats as those produced by modern DSLRs.\n\n"
-						  "For an exahustive list of supported cameras please see below.\n\n",
-						  "<b>",PACKAGE,"</b> is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.\n\n",
-						  "<b>",PACKAGE,"</b> is based on LibRaw ",libraw_version()," which in turn is (C) 2008-2009 LibRaw LLC (info@libraw.org)\n\n",
-						  "Supported cameras:\n\n<small>",NULL);
+	message = g_strconcat("<b>",PACKAGE,"</b> is based on LibRaw\n<small><i>(C) 2008-2010 LibRaw LLC (info@libraw.org)</i></small>\n\n",
+						  "Cameras supported by LibRaw ",libraw_version(),":\n\n<small>",NULL);
 	cameralist = libraw_cameraList();
 	for(i = 0;i < libraw_cameraCount();i++) message = g_strconcat(message,"\t",cameralist[i],"\n",NULL);
 	message = g_strconcat(message,"</small>",NULL);
 	gtk_label_set_markup(GTK_LABEL (dispmessage),message);
 	hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (panarea),dispmessage);
-	gtk_box_pack_end_defaults(GTK_BOX (GTK_DIALOG (abdialog)->vbox),panarea);
-	gtk_widget_show_all(abdialog);
-	gtk_dialog_run(GTK_DIALOG (abdialog));
-	gtk_widget_destroy(abdialog);
+	gtk_box_pack_start_defaults(GTK_BOX (GTK_DIALOG (cldialog)->vbox),panarea);
+	gtk_widget_show_all(cldialog);
+    if (arbutenabled) {
+    	arrow_button_disable(myapp->prevarrowbut);
+    	arrow_button_disable(myapp->nextarrowbut);
+    }
+	gtk_dialog_run(GTK_DIALOG (cldialog));
+	gtk_widget_destroy(cldialog);
+	g_free(message);
+	if (arbutenabled) {
+	   	arrow_button_enable(myapp->prevarrowbut);
+	   	arrow_button_enable(myapp->nextarrowbut);
+	}
 }
